@@ -16,8 +16,8 @@ setupG <- function(group, m, bilevel) {
   } else {
     #if (all.equal(sort(names(m)), sort(group)))
     TRY <- try(as.integer(group)==g)
-    if (class(TRY)=='try-error' || any(!TRY)) stop('Attempting to set group.multiplier is ambiguous if group is not a factor')
-    if (length(m) != length(lev)) stop("Length of group.multiplier must equal number of penalized groups")
+    if (inherits(TRY, 'try-error') || any(!TRY)) stop('Attempting to set group.multiplier is ambiguous if group is not a factor', call.=FALSE)
+    if (length(m) != length(lev)) stop("Length of group.multiplier must equal number of penalized groups", call.=FALSE)
     if (storage.mode(m) != "double") storage.mode(m) <- "double"
   }
   structure(g, levels=lev, m=m)
