@@ -7,7 +7,7 @@ grpreg <- function(X, y, group=1:ncol(X), penalty=c("grLasso", "grMCP", "grSCAD"
 
   # Deprecation support / error checking
   if (!missing(penalty)) {
-    if (penalty[1]=="gBridge") stop("gBridge has been divorced from the grpreg function; use the gBridge() function instead")
+    if (penalty[1]=="gBridge") stop("gBridge has been divorced from the grpreg function; use the gBridge() function instead", call.=FALSE)
     if (penalty[1]=="gMCP") {
       writeLines(strwrap("penalty='gMCP' is deprecated and may not be supported in future versions.  Use penalty='cMCP' instead."))
       penalty <- "cMCP"
@@ -19,16 +19,16 @@ grpreg <- function(X, y, group=1:ncol(X), penalty=c("grLasso", "grMCP", "grSCAD"
   }
   family <- match.arg(family)
   penalty <- match.arg(penalty)
-  if (gamma <= 1 & penalty %in% c("grMCP", "cMCP")) stop("gamma must be greater than 1 for the MC penalty")
-  if (gamma <= 2 & penalty=="grSCAD") stop("gamma must be greater than 2 for the SCAD penalty")
-  if (nlambda < 2) stop("nlambda must be at least 2")
-  if (alpha > 1 | alpha <= 0) stop("alpha must be in (0,1]")
+  if (gamma <= 1 & penalty %in% c("grMCP", "cMCP")) stop("gamma must be greater than 1 for the MC penalty", call.=FALSE)
+  if (gamma <= 2 & penalty=="grSCAD") stop("gamma must be greater than 2 for the SCAD penalty", call.=FALSE)
+  if (nlambda < 2) stop("nlambda must be at least 2", call.=FALSE)
+  if (alpha > 1 | alpha <= 0) stop("alpha must be in (0, 1]", call.=FALSE)
 
   # Construct XG, yy
-  bilevel <- strtrim(penalty,2) != "gr"
+  bilevel <- strtrim(penalty, 2) != "gr"
   yy <- newY(y, family)
   XG <- newXG(X, group, group.multiplier, attr(yy, 'm'), bilevel)
-  if (nrow(XG$X) != length(yy)) stop("X and y do not have the same number of observations")
+  if (nrow(XG$X) != length(yy)) stop("X and y do not have the same number of observations", call.=FALSE)
 
   # Setup lambda
   if (missing(lambda)) {
@@ -44,7 +44,7 @@ grpreg <- function(X, y, group=1:ncol(X), penalty=c("grLasso", "grMCP", "grSCAD"
   # Fit
   n <- length(yy)
   p <- ncol(XG$X)
-  K <- as.numeric(table(XG$g))
+  K <- as.integer(table(XG$g))
   K0 <- as.integer(if (min(XG$g)==0) K[1] else 0)
   K1 <- as.integer(if (min(XG$g)==0) cumsum(K) else c(0, cumsum(K)))
   if (K0) {
@@ -74,7 +74,8 @@ grpreg <- function(X, y, group=1:ncol(X), penalty=c("grLasso", "grMCP", "grSCAD"
   lambda <- lambda[ind]
   df <- df[ind]
   loss <- loss[ind]
-  if (warn & any(iter==max.iter)) warning("Algorithm failed to converge for all values of lambda")
+  if (iter[1] == max.iter) stop("Algorithm failed to converge for any values of lambda.  This indicates a combination of (a) an ill-conditioned feature matrix X and (b) insufficient penalization.  You must fix one or the other for your model to be identifiable.", call.=FALSE)
+  if (warn & any(iter==max.iter)) warning("Algorithm failed to converge for all values of lambda", call.=FALSE)
 
   # Unstandardize
   if (strtrim(penalty,2)=="gr") b <- unorthogonalize(b, XG$X, XG$g)
@@ -85,12 +86,12 @@ grpreg <- function(X, y, group=1:ncol(X), penalty=c("grLasso", "grMCP", "grSCAD"
   varnames <- c("(Intercept)", XG$names)
   ncolY <- attr(yy, 'm')
   if (ncolY > 1) {
-    beta[2:ncolY,] <- sweep(beta[2:ncolY,,drop=FALSE], 2, beta[1,], FUN="+")
+    beta[2:ncolY,] <- sweep(beta[2:ncolY, , drop=FALSE], 2, beta[1,], FUN="+")
     beta <- array(beta, dim=c(ncolY, nrow(beta)/ncolY, ncol(beta)))
     group <- group[-(1:(ncolY-1))]
-    dimnames(beta) <- list(colnames(yy), varnames, round(lambda,digits=4))
+    dimnames(beta) <- list(colnames(yy), varnames, round(lambda, digits=4))
   } else {
-    dimnames(beta) <- list(varnames, round(lambda,digits=4))
+    dimnames(beta) <- list(varnames, round(lambda, digits=4))
   }
 
   val <- structure(list(beta = beta,
