@@ -21,8 +21,8 @@ int sum_rejections(int *x, int n) {
 
 // Group descent update
 void gd_gaussian(double *b, double *x, double *r, int g, int *K1, int *K,
-                       int n, int l, int p, const char *penalty, double lam1, double lam2,
-                       double gamma, SEXP df, double *a, double *maxChange) {
+                 int n, int l, int p, const char *penalty, double lam1, double lam2,
+                 double gamma, SEXP df, double *a, double *maxChange) {
   // Calculate z
   double *z = Calloc(K[g], double);
   for (int j=K1[g]; j<K1[g+1]; j++) z[j-K1[g]] = crossprod(x, r, n, j)/n + a[j];
@@ -48,7 +48,7 @@ void gd_gaussian(double *b, double *x, double *r, int g, int *K1, int *K,
 }
 
 // Scan for violations in rest set
-int check_rest_set(int *e2, int *e, double *xTr, double *X, double *r, int *K1, int *K, double lam, int n, int J) {
+int check_rest_set(int *e2, int *e, double *xTr, double *X, double *r, int *K1, int *K, double lam, double *m, int n, int J) {
   int violations = 0;
   double TOLERANCE = 1e-8;
   for (int g = 0; g < J; g++) {
@@ -58,7 +58,7 @@ int check_rest_set(int *e2, int *e, double *xTr, double *X, double *r, int *K1,
         z[j-K1[g]] = crossprod(X, r, n, j) / n;
       }
       xTr[g] = norm(z, K[g]);
-      if (xTr[g] + TOLERANCE > lam * sqrt(K[g])) {
+      if (xTr[g] + TOLERANCE > lam * m[g] * sqrt(K[g])) {
         e[g] = e2[g] = 1;
         violations++;
       }
@@ -69,7 +69,7 @@ int check_rest_set(int *e2, int *e, double *xTr, double *X, double *r, int *K1,
 }
 
 // Scan for violations in strong set
-int check_strong_set(int *e2, int *e, double *xTr, double *X, double *r, int *K1, int *K, double lam, int n, int J) {
+int check_strong_set(int *e2, int *e, double *xTr, double *X, double *r, int *K1, int *K, double lam, double *m, int n, int J) {
   int violations = 0;
   for (int g = 0; g < J; g++) {
     if (e[g] == 0 && e2[g] == 1) {
@@ -78,7 +78,7 @@ int check_strong_set(int *e2, int *e, double *xTr, double *X, double *r, int *K1
         z[j-K1[g]] = crossprod(X, r, n, j) / n;
       }
       xTr[g] = norm(z, K[g]);
-      if (xTr[g] > lam * sqrt(K[g])) {
+      if (xTr[g] > lam * m[g] * sqrt(K[g])) {
         e[g] = 1;
         violations++;
       }
@@ -237,9 +237,9 @@ int check_rest_set_ssr_bedpp(int *e2, int *e, int *e3, double *xTr, double *X,
 
 
 SEXP gdfit_gaussian(SEXP X_, SEXP y_, SEXP penalty_, SEXP K1_, SEXP K0_, 
-                        SEXP lambda, SEXP lam_max_, SEXP alpha_, SEXP eps_, 
-                        SEXP max_iter_, SEXP gamma_, SEXP group_multiplier, 
-                        SEXP dfmax_, SEXP gmax_, SEXP user_) {
+                    SEXP lambda, SEXP lam_max_, SEXP alpha_, SEXP eps_, 
+                    SEXP max_iter_, SEXP gamma_, SEXP group_multiplier, 
+                    SEXP dfmax_, SEXP gmax_, SEXP user_) {
 
   // Lengths/dimensions
   int n = length(y_);
@@ -264,6 +264,9 @@ SEXP gdfit_gaussian(SEXP X_, SEXP y_, SEXP penalty_, SEXP K1_, SEXP K0_,
   int dfmax = INTEGER(dfmax_)[0];
   int gmax = INTEGER(gmax_)[0];
   int user = INTEGER(user_)[0];
+  for (int g=0; g<J; g++) {
+    if (m[g] != 1) user = 1;
+  }
 
   // Outcome
   SEXP res, beta, iter, df, loss, rejections, safe_rejections;
@@ -289,7 +292,7 @@ SEXP gdfit_gaussian(SEXP X_, SEXP y_, SEXP penalty_, SEXP K1_, SEXP K0_,
   for (int j=0; j<p; j++) a[j] = 0;
   int *e = Calloc(J, int); // ever-active set
   for (int g=0; g<J; g++) e[g] = 0;
-  int converged, lstart = 0, ng, nv, violations;
+  int lstart = 0, ng, nv, violations;
   double shift, l1, l2, maxChange;
 
   // variables for screening
@@ -341,10 +344,10 @@ SEXP gdfit_gaussian(SEXP X_, SEXP y_, SEXP penalty_, SEXP K1_, SEXP K0_,
       ng = 0;
       nv = 0;
       for (int g=0; g<J; g++) {
-      	if (a[K1[g]] != 0) {
-      	  ng++;
-      	  nv = nv + (K1[g+1]-K1[g]);
-      	}
+        if (a[K1[g]] != 0) {
+          ng++;
+          nv = nv + (K1[g+1]-K1[g]);
+        }
       }
       if (ng > gmax || nv > dfmax || tot_iter == max_iter) {
         for (int ll=l; ll<L; ll++) INTEGER(iter)[ll] = NA_INTEGER;
@@ -370,7 +373,6 @@ SEXP gdfit_gaussian(SEXP X_, SEXP y_, SEXP penalty_, SEXP K1_, SEXP K0_,
     while (tot_iter < max_iter) {
       while (tot_iter < max_iter) {
         while (tot_iter < max_iter) {
-          converged = 0;
           INTEGER(iter)[l]++;
           tot_iter++;
           REAL(df)[l] = 0;
@@ -395,11 +397,11 @@ SEXP gdfit_gaussian(SEXP X_, SEXP y_, SEXP penalty_, SEXP K1_, SEXP K0_,
           }
           
           // Check convergence
-	  for (int j=0; j<p; j++) a[j] = b[l*p+j];
-	  if (maxChange < eps*sdy) break;
+          for (int j=0; j<p; j++) a[j] = b[l*p+j];
+          if (maxChange < eps*sdy) break;
         }
         // Scan for violations in strong set
-        violations = check_strong_set(e2, e, xTr, X, r, K1, K, lam[l], n, J);
+        violations = check_strong_set(e2, e, xTr, X, r, K1, K, lam[l], m, n, J);
         if (violations == 0) break;
       }
 
@@ -407,7 +409,7 @@ SEXP gdfit_gaussian(SEXP X_, SEXP y_, SEXP penalty_, SEXP K1_, SEXP K0_,
       if (bedpp_flag) {
         violations = check_rest_set_ssr_bedpp(e2, e, e3, xTr, X, r, K1, K, lam[l], n, J);
       } else {
-        violations = check_rest_set(e2, e, xTr, X, r, K1, K, lam[l], n, J);
+        violations = check_rest_set(e2, e, xTr, X, r, K1, K, lam[l], m, n, J);
       }
       if (violations == 0) {
         REAL(loss)[l] = gLoss(r, n);
